@@ -5,15 +5,13 @@ use warnings;
 use 5.8.1;
 use Path::Class::Dir;
 use Path::Class::File;
-use Mouse::TypeRegistry;
+use Mouse::Util::TypeConstraints;
 use MouseX::Types::Mouse qw(Str ArrayRef);
 use namespace::clean;
 
-use MouseX::Types
-    -declare => [qw(Dir File)]; # export Types
-require Mouse;                  # for Mouse::TypeRegistry (Mouse::load_class)
+use MouseX::Types -declare => [qw(Dir File)]; # export Types
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 class_type $_ => { class => $_ }
     for qw( Path::Class::Dir Path::Class::File );
